==> vue-components-1.5.13.tgz: package/lib/buttons/src/buttonClasses.rd.js <==
const r = {
  outline: {
    primary: {
      class: "bg-primary-100 active:!bg-primary-100 text-primary-600 hover:bg-primary-200 hover:text-primary-800 dark:text-primary-400 dark:bg-primary-900 dark:hover:text-primary-300 dark:hover:bg-primary-800 dark:active:!text-primary-400 dark:active:!bg-primary-900"
    },
    secondary: {
      class: "bg-secondary-100 active:!bg-secondary-100 text-secondary-600 hover:bg-secondary-200 hover:text-secondary-800 dark:text-secondary-400 dark:bg-secondary-600/50 dark:hover:text-secondary-300 dark:hover:bg-secondary-600/70 dark:active:!text-secondary-400 dark:active:!bg-secondary-900"
    },
    info: {
      class: "bg-sky-100 active:!bg-sky-100 text-sky-700 hover:bg-sky-200 hover:text-sky-800 dark:text-sky-400 dark:bg-sky-900 dark:hover:text-sky-300 dark:hover:bg-sky-800 dark:active:!text-sky-400 dark:active:!bg-sky-900"
    },
    success: {
      class: "bg-green-100 active:!bg-green-100 text-green-700 hover:bg-green-200 hover:text-green-800 dark:text-green-400 dark:bg-green-900 dark:hover:text-green-300 dark:hover:bg-green-800 dark:active:!text-green-400 dark:active:!bg-green-900"
    },
    danger: {
      class: "bg-rose-100 active:!bg-rose-100 text-rose-700 hover:bg-rose-200 hover:text-rose-800 dark:text-rose-300 dark:bg-rose-900 dark:bg-opacity-80 dark:hover:text-rose-300 dark:hover:bg-rose-800 dark:active:!text-rose-300 dark:active:!bg-rose-900 !bg-opacity-80"
    },
    warning: {
      class: "bg-yellow-200 active:!bg-yellow-200 text-yellow-800 hover:bg-yellow-300 hover:text-yellow-800 dark:text-yellow-300 dark:bg-yellow-900 dark:hover:text-yellow-200 dark:hover:bg-yellow-800 dark:active:!text-yellow-300 dark:active:!bg-yellow-900"
    },
    neutro: {
      class: "bg-true-gray-200 hover:bg-true-gray-300 text-dark-900 dark:text-white dark:bg-slate-700 dark:hover:bg-slate-600"
    }
  },
  filled: {
    primary: {
      class: "bg-primary-600 active:!bg-primary-600 text-white hover:bg-primary-700 dark:bg-primary-600 dark:hover:bg-primary-500 dark:active:!bg-primary-600"
    },
    secondary: {
      class: "bg-secondary-500 active:!bg-secondary-600 text-white hover:bg-secondary-600 dark:bg-secondary-600 dark:hover:bg-secondary-500 dark:active:!bg-secondary-600"
    },
    info: {
      class: "bg-sky-500 active:!bg-sky-500 text-white hover:bg-sky-600 dark:bg-sky-600 dark:hover:bg-sky-500 dark:active:!bg-sky-600"
    },
    success: {
      class: "bg-green-500 active:!bg-green-500 text-white hover:bg-green-600 dark:bg-green-600 dark:hover:bg-green-500 dark:active:!bg-green-600"
    },
    danger: {
      class: "bg-rose-500 active:!bg-rose-500 text-white hover:bg-rose-600 dark:bg-rose-600 dark:hover:bg-rose-500 dark:active:!bg-rose-600"
    },
    warning: {
      class: "bg-yellow-400 active:!bg-yellow-400 text-white hover:bg-yellow-500 dark:bg-yellow-500 dark:hover:bg-yellow-400 dark:active:!bg-yellow-500"
    },
    neutro: {
      class: "bg-true-gray-200 hover:bg-true-gray-300 text-dark-900 dark:text-white dark:bg-slate-700 dark:hover:bg-slate-600"
    }
  },
  flat: {
    primary: {
      class: "bg-transparent text-primary-600 hover:bg-primary-100 dark:text-primary-400 dark:hover:bg-primary-900 dark:hover:bg-opacity-80 dark:active:bg-opacity-50"
    },
    secondary: {
      class: "bg-transparent text-secondary-600 hover:bg-secondary-100 dark:text-secondary-400 dark:hover:bg-secondary-900 dark:hover:bg-opacity-80 dark:active:bg-opacity-50"
    },
    info: {
      class: "bg-transparent text-sky-700 hover:bg-sky-100 dark:text-sky-400 dark:hover:text-sky-300 dark:hover:bg-sky-900 dark:hover:bg-opacity-80 dark:active:bg-opacity-50"
    },
    success: {
      class: "bg-transparent text-green-700 hover:bg-green-100 dark:text-green-400 dark:hover:text-green-300 dark:hover:bg-green-900 dark:hover:bg-opacity-80 dark:active:bg-opacity-50"
    },
    danger: {
      class: "bg-transparent text-rose-700 hover:bg-rose-100 hover:bg-opacity-80 dark:text-rose-400 dark:hover:text-rose-300 dark:hover:bg-rose-900 dark:hover:bg-opacity-60 dark:active:bg-opacity-40"
    },
    warning: {
      class: "bg-transparent text-yellow-800 hover:bg-yellow-200 hover:text-yellow-800 dark:text-yellow-300 dark:hover:text-yellow-200 dark:hover:bg-yellow-900 dark:hover:bg-opacity-60 dark:active:bg-opacity-40"
    },
    neutro: {
      class: "bg-transparent hover:bg-true-gray-200 text-dark-900 dark:text-white dark:hover:bg-slate-700 dark:active:bg-opacity-50"
    }
  },
  border: {
    primary: {
      class: "border-1 bg-transparent !border-solid border-primary-500 text-primary-600 hover:bg-primary-100 dark:text-primary-400 dark:hover:bg-primary-900 dark:hover:bg-opacity-80 dark:active:bg-opacity-50"
    },
    secondary: {
      class: "border-1 bg-transparent !border-solid border-secondary-500 text-secondary-600 hover:bg-secondary-100 dark:text-secondary-400 dark:hover:bg-secondary-900 dark:hover:bg-opacity-80 dark:active:bg-opacity-50"
    },
    info: {
      class: "border-1 bg-transparent !border-solid border-sky-500 text-sky-700 hover:bg-sky-100 dark:text-sky-400 dark:hover:text-sky-300 dark:hover:bg-sky-900 dark:hover:bg-opacity-80 dark:active:bg-opacity-50"
    },
    success: {
      class: "border-1 bg-transparent !border-solid border-green-500 text-green-700 hover:bg-green-100 dark:text-green-400 dark:hover:text-green-300 dark:hover:bg-green-900 dark:hover:bg-opacity-80 dark:active:bg-opacity-50"
    },
    danger: {
      class: "border-1 bg-transparent !border-solid border-rose-500 text-rose-700 hover:bg-rose-100 hover:bg-opacity-80 dark:text-rose-400 dark:hover:text-rose-300 dark:hover:bg-rose-900 dark:hover:bg-opacity-60 dark:active:bg-opacity-40"
    },
    warning: {
      class: "border-1 bg-transparent !border-solid border-yellow-500 text-yellow-800 hover:bg-yellow-200 hover:text-yellow-800 dark:text-yellow-300 dark:hover:text-yellow-200 dark:hover:bg-yellow-900 dark:hover:bg-opacity-60 dark:active:bg-opacity-40"
    },
    neutro: {
      class: "border-1 bg-transparent !border-solid border-slate-400 dark:border-slate-600 bg-transparent hover:bg-true-gray-100 text-dark-900 dark:text-white dark:hover:bg-slate-700 dark:active:bg-opacity-50"
    }
  }
}, e = {
  primary: "bg-primary-900",
  secondary: "bg-secondary-900",
  info: "bg-sky-900",
  success: "bg-green-900",
  danger: "bg-rose-900",
  warning: "bg-yellow-900",
  neutro: "bg-dark-200"
};
export {
  r as classes,
  e as overlay
};

==> vue-components-1.6.3.tgz: package/lib/buttons/src/buttonClasses.rd.js <==
const r = {
  outline: {
    primary: {
      class: "bg-primary-100 active:!bg-primary-100 text-primary-600 hover:bg-primary-200 hover:text-primary-800 dark:text-primary-400 dark:bg-primary-900 dark:hover:text-primary-300 dark:hover:bg-primary-800 dark:active:!text-primary-400 dark:active:!bg-primary-900"
    },
    secondary: {
      class: "bg-secondary-100 active:!bg-secondary-100 text-secondary-600 hover:bg-secondary-200 hover:text-secondary-800 dark:text-secondary-400 dark:bg-secondary-600/50 dark:hover:text-secondary-300 dark:hover:bg-secondary-600/70 dark:active:!text-secondary-400 dark:active:!bg-secondary-900"
    },
    info: {
      class: "bg-sky-100 active:!bg-sky-100 text-sky-700 hover:bg-sky-200 hover:text-sky-800 dark:text-sky-400 dark:bg-sky-900 dark:hover:text-sky-300 dark:hover:bg-sky-800 dark:active:!text-sky-400 dark:active:!bg-sky-900"
    },
    success: {
      class: "bg-green-100 active:!bg-green-100 text-green-700 hover:bg-green-200 hover:text-green-800 dark:text-green-400 dark:bg-green-900 dark:hover:text-green-300 dark:hover:bg-green-800 dark:active:!text-green-400 dark:active:!bg-green-900"
    },
    danger: {
      class: "bg-rose-100 active:!bg-rose-100 text-rose-700 hover:bg-rose-200 hover:text-rose-800 dark:text-rose-300 dark:bg-rose-900 dark:bg-opacity-80 dark:hover:text-rose-300 dark:hover:bg-rose-800 dark:active:!text-rose-300 dark:active:!bg-rose-900 !bg-opacity-80"
    },
    warning: {
      class: "bg-yellow-200 active:!bg-yellow-200 text-yellow-800 hover:bg-yellow-300 hover:text-yellow-800 dark:text-yellow-300 dark:bg-yellow-900 dark:hover:text-yellow-200 dark:hover:bg-yellow-800 dark:active:!text-yellow-300 dark:active:!bg-yellow-900"
    },
    neutro: {
      class: "bg-rdSurfaceB-200 hover:bg-rdSurfaceB-300 text-dark-900 dark:text-white dark:!bg-rdSurface-700 dark:hover:bg-rdSurface-600"
    }
  },
  filled: {
    primary: {
      class: "bg-primary-600 active:!bg-primary-600 text-white hover:bg-primary-700 dark:bg-primary-600 dark:hover:bg-primary-500 dark:active:!bg-primary-600"
    },
    secondary: {
      class: "bg-secondary-500 active:!bg-secondary-600 text-white hover:bg-secondary-600 dark:bg-secondary-600 dark:hover:bg-secondary-500 dark:active:!bg-secondary-600"
    },
    info: {
      class: "bg-sky-500 active:!bg-sky-500 text-white hover:bg-sky-600 dark:bg-sky-600 dark:hover:bg-sky-500 dark:active:!bg-sky-600"
    },
    success: {
      class: "bg-green-500 active:!bg-green-500 text-white hover:bg-green-600 dark:bg-green-600 dark:hover:bg-green-500 dark:active:!bg-green-600"
    },
    danger: {
      class: "bg-rose-500 active:!bg-rose-500 text-white hover:bg-rose-600 dark:bg-rose-600 dark:hover:bg-rose-500 dark:active:!bg-rose-600"
    },
    warning: {
      class: "bg-yellow-400 active:!bg-yellow-400 text-white hover:bg-yellow-500 dark:bg-yellow-500 dark:hover:bg-yellow-400 dark:active:!bg-yellow-500"
    },
    neutro: {
      class: "bg-rdSurfaceB-200 hover:bg-rdSurfaceB-300 text-dark-900 dark:text-white dark:!bg-rdSurface-700 dark:hover:bg-rdSurface-600"
    }
  },
  flat: {
    primary: {
      class: "bg-transparent text-primary-600 hover:bg-primary-100 dark:text-primary-400 dark:hover:bg-primary-900 dark:hover:bg-opacity-80 dark:active:bg-opacity-50"
    },
    secondary: {
      class: "bg-transparent text-secondary-600 hover:bg-secondary-100 dark:text-secondary-400 dark:hover:bg-secondary-900 dark:hover:bg-opacity-80 dark:active:bg-opacity-50"
    },
    info: {
      class: "bg-transparent text-sky-700 hover:bg-sky-100 dark:text-sky-400 dark:hover:text-sky-300 dark:hover:bg-sky-900 dark:hover:bg-opacity-80 dark:active:bg-opacity-50"
    },
    success: {
      class: "bg-transparent text-green-700 hover:bg-green-100 dark:text-green-400 dark:hover:text-green-300 dark:hover:bg-green-900 dark:hover:bg-opacity-80 dark:active:bg-opacity-50"
    },
    danger: {
      class: "bg-transparent text-rose-700 hover:bg-rose-100 hover:bg-opacity-80 dark:text-rose-400 dark:hover:text-rose-300 dark:hover:bg-rose-900 dark:hover:bg-opacity-60 dark:active:bg-opacity-40"
    },
    warning: {
      class: "bg-transparent text-yellow-800 hover:bg-yellow-200 hover:text-yellow-800 dark:text-yellow-300 dark:hover:text-yellow-200 dark:hover:bg-yellow-900 dark:hover:bg-opacity-60 dark:active:bg-opacity-40"
    },
    neutro: {
      class: "bg-transparent hover:bg-rdSurfaceB-200 text-dark-900 dark:text-white dark:hover:bg-rdSurface-700 dark:active:bg-opacity-50"
    }
  },
  border: {
    primary: {
      class: "border-1 bg-transparent !border-solid border-primary-500 text-primary-600 hover:bg-primary-100 dark:text-primary-400 dark:hover:bg-primary-900 dark:hover:bg-opacity-80 dark:active:bg-opacity-50"
    },
    secondary: {
      class: "border-1 bg-transparent !border-solid border-secondary-500 text-secondary-600 hover:bg-secondary-100 dark:text-secondary-400 dark:hover:bg-secondary-900 dark:hover:bg-opacity-80 dark:active:bg-opacity-50"
    },
    info: {
      class: "border-1 bg-transparent !border-solid border-sky-500 text-sky-700 hover:bg-sky-100 dark:text-sky-400 dark:hover:text-sky-300 dark:hover:bg-sky-900 dark:hover:bg-opacity-80 dark:active:bg-opacity-50"
    },
    success: {
      class: "border-1 bg-transparent !border-solid border-green-500 text-green-700 hover:bg-green-100 dark:text-green-400 dark:hover:text-green-300 dark:hover:bg-green-900 dark:hover:bg-opacity-80 dark:active:bg-opacity-50"
    },
    danger: {
      class: "border-1 bg-transparent !border-solid border-rose-500 text-rose-700 hover:bg-rose-100 hover:bg-opacity-80 dark:text-rose-400 dark:hover:text-rose-300 dark:hover:bg-rose-900 dark:hover:bg-opacity-60 dark:active:bg-opacity-40"
    },
    warning: {
      class: "border-1 bg-transparent !border-solid border-yellow-500 text-yellow-800 hover:bg-yellow-200 hover:text-yellow-800 dark:text-yellow-300 dark:hover:text-yellow-200 dark:hover:bg-yellow-900 dark:hover:bg-opacity-60 dark:active:bg-opacity-40"
    },
    neutro: {
      class: "border-1 bg-transparent !border-solid !border-theme bg-transparent hover:bg-rdSurfaceB-100 text-dark-900 dark:text-white dark:hover:bg-rdSurface-700 dark:active:bg-opacity-50"
    }
  }
}, e = {
  primary: "bg-primary-900",
  secondary: "bg-secondary-900",
  info: "bg-sky-900",
  success: "bg-green-900",
  danger: "bg-rose-900",
  warning: "bg-yellow-900",
  neutro: "bg-dark-200"
};
export {
  r as classes,
  e as overlay
};
